from AlbotOnline import AlbotConnection as AO

class TwitterSampler:

    def __init__(self, IP = '127.0.0.1', Port = 4000):
        self.connection = AO.AlbotConnection(bufferSize=1024, IP=IP, Port=Port, gameOverObj=self)
        self.width = 2048
        self.height = 2048

    def getSample(self, x, y):
        self.connection.sendString(str(x) + " " + str(y))
        response = self.connection.getNextString()

        if(response == "HIT"):
            return True
        elif(response == "MISS"):
            return False

        return response


import AlbotOnline.TwitterMonteCarlo.Twitter as Albot
import random

sampler = Albot.TwitterSampler()

'''
#Exhaustive Sampling
for y in range(2048):
    for x in range(2048):
        sampler.getSample(x, y)
'''

#Random Sampling
while(True):
    x = random.randint(0, sampler.width)
    y = random.randint(0, sampler.height)
    sampler.getSample(x, y)